Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(593)

Unified Diff: ui/webui/resources/js/cr/ui/focus_row.js

Issue 2749513004: MD Settings: adjust iron-list focus row behaviors. (Closed)
Patch Set: add tests for new focusRowBehavior Created 3 years, 9 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: ui/webui/resources/js/cr/ui/focus_row.js
diff --git a/ui/webui/resources/js/cr/ui/focus_row.js b/ui/webui/resources/js/cr/ui/focus_row.js
index 652b0353f61a2ab23e4fb8dda774747ac55322f6..b2488510e13ef70d75d23aace37e97d39df4a50b 100644
--- a/ui/webui/resources/js/cr/ui/focus_row.js
+++ b/ui/webui/resources/js/cr/ui/focus_row.js
@@ -105,13 +105,18 @@ cr.define('cr.ui', function() {
* to indicate they're equivalent.
*
* @param {string} type The type of element to track focus of.
* @param {string} query The selector of the element from this row's root.
hcarmona 2017/03/16 21:31:54 nit: rename |query| to |selector|
scottchen 2017/03/17 21:26:59 good idea, wasn't sure what to name it.
+ * row's root, or the element itself.
* @return {boolean} Whether a new item was added.
*/
addItem: function(type, query) {
assert(type);
- var element = this.root.querySelector(query);
+ var element;
+ if (query instanceof HTMLElement)
+ element = query;
+ else
+ element = this.root.querySelector(/** @type {string} */ (query));
if (!element)
return false;
@@ -105,13 +105,18 @@ cr.define('cr.ui', function() {
*
* @param {string} type The type of element to track focus of.
- * @param {string} query The selector of the element from this row's root.
+ * @param {string|HTMLElement} query The selector of the element from this
hcarmona 2017/03/16 21:31:54 nit: rename |query| to |selector|
scottchen 2017/03/17 21:26:59 good idea, wasn't sure what to name it.

Powered by Google App Engine
This is Rietveld 408576698